@@ -5,5 +5,5 @@ test_that("best_duplicate", {
     item2 = c(NA, 1, 1, 2, 3),
     item3 = c(NA, 1, 1, 2, 3)
   )
-  expect_snapshot(best_duplicate(df1, id = "id"))
+  expect_snapshot(suppressMessages(best_duplicate(df1, id = "id")))
 })
